@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook Kontact Plugin.
 
-  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,8 @@
 
 #include <KontactInterface/UniqueAppHandler>
 
-namespace KontactInterface {
+namespace KontactInterface
+{
 class Plugin;
 }
 
