@@ -1,26 +1,25 @@
 /*
   This file is part of KAddressBook.
 
-  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kaddressbookpart.h"
-#include "mainwidget.h"
 #include "kaddressbookmigrateapplication.h"
+#include "mainwidget.h"
 
 #include "kaddressbook_debug.h"
+#include <KActionCollection>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <QAction>
-#include <KActionCollection>
 #include <QIcon>
 
 #include <QVBoxLayout>
 
-K_PLUGIN_FACTORY(KAddressBookFactory, registerPlugin<KAddressBookPart>();
-                 )
+K_PLUGIN_FACTORY(KAddressBookFactory, registerPlugin<KAddressBookPart>();)
 
 KAddressBookPart::KAddressBookPart(QWidget *parentWidget, QObject *parent, const QVariantList &)
     : KParts::Part(parent)
@@ -33,7 +32,7 @@ KAddressBookPart::KAddressBookPart(QWidget *parentWidget, QObject *parent, const
     QWidget *canvas = new QWidget(parentWidget);
     canvas->setFocusPolicy(Qt::ClickFocus);
     setWidget(canvas);
-    auto *topLayout = new QVBoxLayout(canvas);
+    auto topLayout = new QVBoxLayout(canvas);
 
     mMainWidget = new MainWidget(this, canvas);
     initAction();
