@@ -12,7 +12,8 @@
 class QWidget;
 class KConfigGroup;
 
-namespace KAddressBook {
+namespace KAddressBook
+{
 /**
  * @short Methods to save and restore the UI state of an application.
  *
@@ -31,19 +32,20 @@ namespace KAddressBook {
  * @author Volker Krause <vkrause@kde.org>
  * @since 4.5
  */
-namespace UiStateSaver {
+namespace UiStateSaver
+{
 /**
-   * Saves the state of @p widget and all its sub-widgets to @p config.
-   * @param widget The top-level widget which state should be saved.
-   * @param config The config group the settings should be written to.
-   */
+ * Saves the state of @p widget and all its sub-widgets to @p config.
+ * @param widget The top-level widget which state should be saved.
+ * @param config The config group the settings should be written to.
+ */
 KADDRESSBOOK_EXPORT void saveState(QWidget *widget, KConfigGroup &config);
 
 /**
-   * Restores the UI state of @p widget and all its sub-widgets from @p config.
-   * @param widget The top-level widget which state should be restored.
-   * @param config The config gorup the settings should be read from.
-   */
+ * Restores the UI state of @p widget and all its sub-widgets from @p config.
+ * @param widget The top-level widget which state should be restored.
+ * @param config The config gorup the settings should be read from.
+ */
 KADDRESSBOOK_EXPORT void restoreState(QWidget *widget, const KConfigGroup &config);
 }
 }
